<?php
$translations = array(
	'General_Locale' => 'et_ET.UTF-8',
	'General_TranslatorName' => 'Kaido Toomingas',
	'General_TranslatorEmail' => 'toomingas.k@gmail.com',
	'General_EnglishLanguageName' => 'Estonian',
	'General_OriginalLanguageName' => 'Eesti keel',
	'General_API' => 'API',
	'General_Widgets' => 'Moodulid',
	'General_Settings' => 'Seaded',
	'General_GiveUsYourFeedback' => 'Tagasiside!',
	'General_Unknown' => 'Tundmatu',
	'General_Required' => '%s on nõutav',
	'General_Error' => 'Viga',
	'General_Warning' => 'Hoiatus',
	'General_BackToHomepage' => 'Tagasi esilehele',
	'General_Yes' => 'Jah',
	'General_No' => 'Ei',
	'General_Delete' => 'Kustuta',
	'General_Edit' => 'Muuda',
	'General_Ok' => 'Ok',
	'General_Close' => 'Sulge',
	'General_Logout' => 'Logi välja',
	'General_Done' => 'Tehtud',
	'General_LoadingData' => 'Laen infot...',
	'General_Next' => 'Järgmine',
	'General_Previous' => 'Eelmine',
	'General_Search' => 'Otsi',
	'General_Others' => 'Teised',
	'General_Table' => 'Tabel',
	'General_Piechart' => 'Sektordiagramm',
	'General_TagCloud' => 'sildipilv',
	'General_VBarGraph' => 'Vertikaaltulbad',
	'General_Refresh' => 'Värskenda lehte',
	'General_Visitors' => 'Külastajad',
	'General_Export' => 'Expordi',
	'General_ErrorRequest' => 'Oops… nõude esitamisel tekkis viga, palun proovi uuesi.',
	'General_ColumnNbUniqVisitors' => 'Unikaalsed külastajad',
	'General_ColumnNbVisits' => 'Külastused',
	'General_ColumnLabel' => 'Tiitel',
	'General_Save' => 'Salvesta',
	'General_Website' => 'Veebileht',
	'General_NoDataForGraph' => 'Graafik - infot pole veel',
	'General_NoDataForTagCloud' => 'Sildipilv - Infot ei ole veel.',
	'Actions_Actions' => 'Tegevused',
	'Actions_SubmenuPages' => 'Vaadatud lehed',
	'Actions_SubmenuOutlinks' => 'Väljuvad lingid',
	'Actions_SubmenuDownloads' => 'Allalaadimised',
	'API_LoadedAPIs' => 'Edukalt laetud %s API-id',
	'CoreHome_CategoryNoData' => 'Informatsioon puudub selles kategoorias. Proovi "Include all population".',
	'CoreHome_ShowJSCode' => 'Näita sisestatavat javaacript koodi',
	'CoreHome_PageOf_js' => '%1$s - %2$s',
	'CoreHome_PeriodDay' => 'Päev',
	'CoreHome_PeriodWeek' => 'Nädal',
	'CoreHome_PeriodMonth' => 'Kuu',
	'CoreHome_PeriodYear' => 'Aasta',
	'CoreHome_DaySu_js' => 'P',
	'CoreHome_DayMo_js' => 'E',
	'CoreHome_DayTu_js' => 'T',
	'CoreHome_DayWe_js' => 'K',
	'CoreHome_DayTh_js' => 'N',
	'CoreHome_DayFr_js' => 'R',
	'CoreHome_DaySa_js' => 'L',
	'CoreHome_ShortDay_1_js' => 'Pühap',
	'CoreHome_ShortDay_2_js' => 'Esmasp',
	'CoreHome_ShortDay_3_js' => 'Teisip',
	'CoreHome_ShortDay_4_js' => 'Kolmap',
	'CoreHome_ShortDay_5_js' => 'Neljap',
	'CoreHome_ShortDay_6_js' => 'Reede',
	'CoreHome_ShortDay_7_js' => 'Laup',
	'CoreHome_LongDay_1_js' => 'Pühapäev',
	'CoreHome_LongDay_2_js' => 'Esmaspäev',
	'CoreHome_LongDay_3_js' => 'Teisipäev',
	'CoreHome_LongDay_4_js' => 'Kolmapäev',
	'CoreHome_LongDay_5_js' => 'Neljapäev',
	'CoreHome_LongDay_6_js' => 'Reede',
	'CoreHome_LongDay_7_js' => 'Laupäev',
	'CoreHome_ShortMonth_1_js' => 'Jaan',
	'CoreHome_ShortMonth_2_js' => 'Veebr',
	'CoreHome_ShortMonth_3_js' => 'Märts',
	'CoreHome_ShortMonth_4_js' => 'Apr',
	'CoreHome_ShortMonth_5_js' => 'Mai',
	'CoreHome_ShortMonth_6_js' => 'Juuni',
	'CoreHome_ShortMonth_7_js' => 'Juuli',
	'CoreHome_ShortMonth_8_js' => 'Aug',
	'CoreHome_ShortMonth_9_js' => 'Sept',
	'CoreHome_ShortMonth_10_js' => 'Okt',
	'CoreHome_ShortMonth_11_js' => 'Nov',
	'CoreHome_ShortMonth_12_js' => 'Dets',
	'CoreHome_MonthJanuary_js' => 'Jaanuar',
	'CoreHome_MonthFebruary_js' => 'Veebruar',
	'CoreHome_MonthMarch_js' => 'Märts',
	'CoreHome_MonthApril_js' => 'Aprill',
	'CoreHome_MonthMay_js' => 'Mai',
	'CoreHome_MonthJune_js' => 'Juuni',
	'CoreHome_MonthJuly_js' => 'Juuli',
	'CoreHome_MonthAugust_js' => 'August',
	'CoreHome_MonthSeptember_js' => 'September',
	'CoreHome_MonthOctober_js' => 'Oktoober',
	'CoreHome_MonthNovember_js' => 'November',
	'CoreHome_MonthDecember_js' => 'Detsember',
	'CorePluginsAdmin_Plugins' => 'Pluginad',
	'CorePluginsAdmin_PluginsManagement' => 'Pluginate haldus',
	'CorePluginsAdmin_MainDescription' => 'Plugins võimendavad ja suurendavad Piwik-i funktsionaalsust. Kui plugin on installeeritud ja aktiveeritud saad seda sisse ja välja lülitada siin.',
	'CorePluginsAdmin_Version' => 'Versioon',
	'CorePluginsAdmin_Status' => 'Olek',
	'CorePluginsAdmin_Action' => 'Tegevus',
	'CorePluginsAdmin_PluginHomepage' => 'Plugina koduleht',
	'CorePluginsAdmin_Activated' => 'Aktiveeritud',
	'CorePluginsAdmin_Active' => 'Aktiivne',
	'CorePluginsAdmin_Inactive' => 'Mitteaktiivne',
	'CorePluginsAdmin_Deactivate' => 'Lülita välja',
	'CorePluginsAdmin_Activate' => 'Aktiveeri',
	'CorePluginsAdmin_MenuPlugins' => 'Pluginad',
	'CoreUpdater_UpdateTitle' => 'Piwik › Uuendus',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Sinu piwik-i andmebaas on vananenud, enne jätkamist pead uuendama.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Käesolevad puginad uuendatakse: %s.',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Uuendamise protsess võtab veidi aega, palun ole kannatlik.',
	'CoreUpdater_UpgradePiwik' => 'Uuenda Piwik',
	'CoreUpdater_HelpMessageContent' => 'Vaata %1$s Piwik KKK %2$s milles selgitadakse tavapäraste probleemide põhjuseid ja lahendusi. %3$s Kui sa ei leia lahendust, siis küsi oma süsteemi administraatoritelt abi- nad võivad aidata juhul, kui need vead on seotud serveri või MySQL seadetega.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kriitiline viga uuendamise protsessi ajal:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Uuendamine edukalt lõpetatud, siiski esines protsessis vigu. Palun tutvu ülal vigade kirjeldustega. Saamaks rohkem abi:',
	'CoreUpdater_UpgradeComplete' => 'Uuendamine lõpuni viidud!',
	'CoreUpdater_WarningMessages' => 'Hoiatussõnumid:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Viga plugina uuendamisel:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Lülitame automaatselt välja järgnevalt pluginad: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik edukalt uuendatud!',
	'CoreUpdater_ContinueToPiwik' => 'Jätka Piwikiga',
	'Dashboard_Dashboard' => 'Töölaud',
	'Dashboard_DeleteWidgetConfirm' => 'Oled sa kindel selle mooduli kustutamises oma töölaualt?',
	'Dashboard_SelectWidget' => 'Vali töölauale lisatav moodul',
	'Dashboard_TitleWidgetInDashboard_js' => 'Moodul on juba töölaual',
	'Dashboard_TitleClickToAdd_js' => 'Kliki lisamaks töölauale',
	'Dashboard_LoadingWidget_js' => 'Laen moodulit, palun oota...',
	'Dashboard_WidgetNotFound_js' => 'Moodulit ei leitud',
	'DBStats_DatabaseUsage' => 'Andmebaasi kasutus',
	'DBStats_MainDescription' => 'Piwik salvestab kõik veebianalüütika andmed Mysql andmebaasi. Hetkel, Piwiki tabelid kasutavad %s.',
	'DBStats_Table' => 'Tabel',
	'DBStats_DataSize' => 'Andmemaht',
	'DBStats_IndexSize' => 'Indeksi maht',
	'Installation_Installation' => 'Installatsioon',
	'Installation_InstallationStatus' => 'Installatiooni olek',
	'Installation_PercentDone' => '%s %% Tehtud',
	'Installation_NoConfigFound' => 'Piwiki konfguratsioonifaili ei leitud, kuid sa üritasid minna Piwiki lehele.<br /><b>  » Võid <a href=\'index.php\'>installeerida Piwiko</a></b><br /><small>Kui Piwik on varem installeeritud ja sul on andmebaasis tabeleid, siis ei ole põhjust muretsemiseks saad taaskasutada ja säilitada olemasolevad andmed!</small>',
	'Installation_JsTag' => 'Javascript tag',
	'Installation_Congratulations' => 'Õnnitleme',
	'Installation_CongratulationsHelp' => '<p>Õnnitlused! Sinu Piwiki Installatsioon on edukalt lõpuni viidud.</p><p>Sisesta javascript kood oma lehele ja jää külastusi ootama!</p>',
	'Installation_SetupWebsite' => 'Seadista veebileht',
	'Installation_SetupWebsiteError' => 'Veebilehe lisamisel tekkis viga',
	'Installation_SystemCheck' => 'Süsteemi kontroll',
	'Installation_SystemCheckPhp' => 'PHP versioon',
	'Installation_SystemCheckWriteDirsHelp' => 'Parandamaks seda viga linux süsteemis, trüki sisse käsk/käsud.',
	'Installation_SystemCheckMemoryLimit' => 'Mälu limiit',
	'Installation_SystemCheckMemoryLimitHelp' => 'Suure liiklusega veebileht võib vajada arhiveerimiseks rohkem mälu, kui hetkel lubatud.<br />Vaata üle oma memory_limit oma php.ini failis, kui see osutub vajalikuks.',
	'Installation_SystemCheckGDHelp' => 'The sparklines (small graphs) will not work.',
	'Installation_SystemCheckTimeLimitHelp' => 'Suure liiklusega veebilehe puhul, või arhiveerimisprotssess võtta rohkem aega, kui hetkel lubatud.<br />Vaata direktiiv max_execution_time  oma php.ini failis, kui see on vajalik',
	'Installation_SystemCheckError' => 'Ilmnes viga - Enne jätkamist tuleb see parandada.',
	'Installation_SystemCheckWarning' => 'Piwik toimib normaalselt, kuid osad võimalused võivad puududa.',
	'Installation_Tables' => 'Tabelite loomine',
	'Installation_TablesFound' => 'Andmebaasist leiti järgnevad tabelid',
	'Installation_TablesWarningHelp' => 'Nüüd saad valida, kas kasutad olemasolevaid tabeleid ja andmeid või lood uued tabelid.',
	'Installation_TablesReuse' => 'Taaskasuta olemasolevaid tabeleid',
	'Installation_TablesDelete' => 'Kustuta leitud tabelid',
	'Installation_TablesDeletedSuccess' => 'Olemasolevad tabelid kustutatud',
	'Installation_TablesCreatedSuccess' => 'Tabelid loodud!',
	'Installation_DatabaseCreatedSuccess' => '%s andmebaas loodud!',
	'Installation_Welcome' => 'Tere tulemast!',
	'Installation_WelcomeHelp' => '<p>Piwik on vabavaraline veebianalüüika tarkvara, mis teeb lihtsaks oma külastajate kohta andmete kogumise ja nende analüüsimise.</p><p>See protsess sisaldab %s sammu ja võtab aega u. 5 minutit.</p>',
	'Login_LoginPasswordNotCorrect' => 'Kasutajanimi & salasõna olid valed',
	'Login_Password' => 'Salasõna',
	'Login_LoginOrEmail' => 'Kasutajanimi või E-mail',
	'Login_LogIn' => 'Sisene',
	'Login_Logout' => 'Välju',
	'Login_LostYourPassword' => 'Kaotasid oma salasõna?',
	'Login_InvalidUsernameEmail' => 'Vale kasutajanimi ja/või e-maili address',
	'Login_ContactAdmin' => 'Võimalik põhjus: sinu majutusel on mail() funktsioon välja lülitatud. <br />Palun kontakteeru administraatoriga.',
	'Provider_WidgetProviders' => 'Pakkujad',
	'Provider_SubmenuLocationsProvider' => 'Asukoht & pakkuja',
	'Referers_Referers' => 'Viitajad',
	'Referers_SearchEngines' => 'Otsingumootorid',
	'Referers_Keywords' => 'Võtmesõnad',
	'Referers_DirectEntry' => 'Otse sisenetud',
	'Referers_Websites' => 'Veebilehed',
	'Referers_Campaigns' => 'Kampaaniad',
	'Referers_Evolution' => 'Perioodi üldareng',
	'Referers_Type' => 'Viitaja tüüp',
	'Referers_TypeDirectEntries' => '%s otse sisenemist',
	'Referers_TypeSearchEngines' => '%s otsomootoritest',
	'Referers_TypeWebsites' => '%s veebilehtedelt',
	'Referers_TypeCampaigns' => '%s kampaaniatest',
	'Referers_SubmenuSearchEngines' => 'Otsimootorid & võtmesõnad',
	'Referers_SubmenuWebsites' => 'Veebilehed',
	'Referers_SubmenuCampaigns' => 'Kampaaniad',
	'Referers_WidgetKeywords' => 'Võtmesõnade nimistu',
	'Referers_WidgetCampaigns' => 'Kampaaniate nimistu',
	'Referers_WidgetExternalWebsites' => 'Väliste viitajate nimekiri',
	'Referers_WidgetSearchEngines' => 'Parimad otsimootorid',
	'Referers_WidgetOverview' => 'Ülevaade',
	'SitesManager_Sites' => 'Sites',
	'SitesManager_WebsitesManagement' => 'Veebilehe haldamine',
	'SitesManager_MainDescription' => 'Sinu veebianalüütika vajab veebilehti, mida hallata! Lisa, uuenda, kustuta veebilehti, ja näita Javascript koodi mida lisada veebilehtedele.',
	'SitesManager_NoWebsites' => 'Sul pole saite mida administreerida.',
	'SitesManager_AddSite' => 'Lisa uus sait',
	'SitesManager_Urls' => 'URL-id',
	'SitesManager_MenuSites' => 'Saidid',
	'SitesManager_DeleteConfirm_js' => 'Oled sa kindel %s kustutamises?',
	'SitesManager_ExceptionDeleteSite' => 'Seda veebilehte ei ole võimalik kustutada, sest see on ainuke registreeritud leht selles andmebaasis. Lisa ennem uus leht ja siis kustuta see leht.',
	'SitesManager_ExceptionNoUrl' => 'Pead määratlema vähemasti ühe saidil oleva URL-i.',
	'SitesManager_ExceptionEmptyName' => 'Saidi nimi ei saa olla tühi.',
	'SitesManager_ExceptionInvalidUrl' => 'Aadress \'%s\' ei ole kehtiv veebiaadress.',
	'TranslationsAdmin_MenuTranslations' => 'Tõlked',
	'TranslationsAdmin_MenuLanguages' => 'Keeled',
	'TranslationsAdmin_LanguageCode' => 'Keele kood',
	'TranslationsAdmin_Definition' => 'Definitsioon',
	'TranslationsAdmin_DefaultString' => 'Vaikimisi keel (Inglise keel)',
	'TranslationsAdmin_TranslationString' => 'Tõlke tõmmis (Praegune keel: %s)',
	'TranslationsAdmin_Translations' => 'Tõlked',
	'TranslationsAdmin_FixPermissions' => 'Palun korrasta failisüsteemi õigused',
	'TranslationsAdmin_AddLanguage' => 'Lisa keel',
	'TranslationsAdmin_Export' => 'Ekspordi keel',
	'TranslationsAdmin_Import' => 'Impordi keel',
	'UserCountry_Country' => 'Riik',
	'UserCountry_Continent' => 'Kontinent',
	'UserCountry_DistinctCountries' => '%s eri riigist',
	'UserCountry_SubmenuLocations' => 'Asukohad',
	'UserCountry_country_ac' => 'Ascension Saared',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'Ühendatud Araabia-Emiraadid',
	'UserCountry_country_af' => 'Afganistaan',
	'UserCountry_country_ag' => 'Antigua ja Barbados',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albaania',
	'UserCountry_country_am' => 'Armeenia',
	'UserCountry_country_an' => 'Hollandi Antillid',
	'UserCountry_country_ao' => 'Angoola',
	'UserCountry_country_aq' => 'Antartika',
	'UserCountry_country_ar' => 'Argentiina',
	'UserCountry_country_as' => 'Ameerika Samoa',
	'UserCountry_country_at' => 'Austria',
	'UserCountry_country_au' => 'Austraalia',
	'UserCountry_country_aw' => 'Aruuba',
	'UserCountry_country_az' => 'Azerbaijan',
	'UserCountry_country_ba' => 'Bosnia ja Hertsegoviina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Belgia',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgaaria',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bm' => 'Bermuuda',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Boliivia',
	'UserCountry_country_br' => 'Brasiilia',
	'UserCountry_country_bs' => 'Bahama',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bv' => 'Bouvet Saared',
	'UserCountry_country_bw' => 'Botsvaana',
	'UserCountry_country_by' => 'Valgevene',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Kanada',
	'UserCountry_country_cc' => 'Kookossaared',
	'UserCountry_country_cd' => 'Kongo, Demokraatlik vabariik',
	'UserCountry_country_cf' => 'Kesk-Aafrika vabariik',
	'UserCountry_country_cg' => 'Kongo',
	'UserCountry_country_ch' => 'Sveitsi',
	'UserCountry_country_ci' => 'Cote D\'Ivoire',
	'UserCountry_country_ck' => 'Cooki saared',
	'UserCountry_country_cl' => 'Tsiili',
	'UserCountry_country_cm' => 'Kamerun',
	'UserCountry_country_cn' => 'Hiina',
	'UserCountry_country_co' => 'Kolumbia',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Serbia Montenegro',
	'UserCountry_country_cu' => 'Kuuba',
	'UserCountry_country_cv' => 'Kap-Verde',
	'UserCountry_country_cx' => 'Jõulusaar',
	'UserCountry_country_cy' => 'Küpros',
	'UserCountry_country_cz' => 'Tsehhi Vabariik',
	'UserCountry_country_de' => 'Saksamaa',
	'UserCountry_country_dj' => 'Djibouti (riik ja linn)',
	'UserCountry_country_dk' => 'Taani',
	'UserCountry_country_dm' => 'Dominikaani',
	'UserCountry_country_do' => 'Dominikaani Vabariik',
	'UserCountry_country_dz' => 'Alzeeria',
	'UserCountry_country_ec' => 'Ecuador',
	'UserCountry_country_ee' => 'Estonia',
	'UserCountry_country_eg' => 'Egiptus',
	'UserCountry_country_eh' => 'Lääne-Sahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Hispaania',
	'UserCountry_country_et' => 'Etioopia',
	'UserCountry_country_fi' => 'Soome',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Falklandi saared',
	'UserCountry_country_fm' => 'Mirkoneesia, Federated States of',
	'UserCountry_country_fo' => 'Fääri saared',
	'UserCountry_country_fr' => 'Prantsusmaa',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Suurbritannia',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Gruusia',
	'UserCountry_country_gf' => 'Prantsuse Guyana',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Gröönimaa',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Ginea',
	'UserCountry_country_gp' => 'Guadelope',
	'UserCountry_country_gq' => 'Ekvatoriaal-Guinea',
	'UserCountry_country_gr' => 'Kreeka',
	'UserCountry_country_gs' => 'Lõuna Georgia ja Lõuna Sandwichi saared',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heard Saar ja McDonald-i saared',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Croatia',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Hungari',
	'UserCountry_country_id' => 'Indoneesia',
	'UserCountry_country_ie' => 'Iirimaa',
	'UserCountry_country_il' => 'Iisrael',
	'UserCountry_country_im' => 'Mani Saared',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'Briti India ookeani ala',
	'UserCountry_country_iq' => 'Iraak',
	'UserCountry_country_ir' => 'Iraan, Islamic Republic of',
	'UserCountry_country_is' => 'Island',
	'UserCountry_country_it' => 'Itaalia',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaika',
	'UserCountry_country_jo' => 'Jordaania',
	'UserCountry_country_jp' => 'Jaapan',
	'UserCountry_country_ke' => 'Keenia',
	'UserCountry_country_kg' => 'Kyrgyzstan',
	'UserCountry_country_kh' => 'Kamboodia',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comoros',
	'UserCountry_country_kn' => 'Saint Kitts and Nevis',
	'UserCountry_country_kp' => 'Korea, Democratic People\'s Republic of',
	'UserCountry_country_kr' => 'Korea, Republic of',
	'UserCountry_country_kw' => 'Kuweit',
	'UserCountry_country_ky' => 'Cayman Saared',
	'UserCountry_country_kz' => 'Kazakhstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Liibanon',
	'UserCountry_country_lc' => 'Saint Lucia',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Libeeria',
	'UserCountry_country_ls' => 'Lesoto',
	'UserCountry_country_lt' => 'Leedu',
	'UserCountry_country_lu' => 'Luxembourg',
	'UserCountry_country_lv' => 'Läti',
	'UserCountry_country_ly' => 'Liibüa',
	'UserCountry_country_ma' => 'Morocco',
	'UserCountry_country_mc' => 'Monako',
	'UserCountry_country_md' => 'Moldova, Republic of',
	'UserCountry_country_mg' => 'Madagaskar',
	'UserCountry_country_mh' => 'Marshalli Saared',
	'UserCountry_country_mk' => 'Makedoonia',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongoolia',
	'UserCountry_country_mo' => 'Macau',
	'UserCountry_country_mp' => 'Põhja Mariana Saared',
	'UserCountry_country_mq' => 'Martinique',
	'UserCountry_country_mr' => 'Mauritania',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauritius',
	'UserCountry_country_mv' => 'Maldiivid',
	'UserCountry_country_mw' => 'Malaavi',
	'UserCountry_country_mx' => 'Mehiko',
	'UserCountry_country_my' => 'Malaisia',
	'UserCountry_country_mz' => 'Mosambiik',
	'UserCountry_country_na' => 'Namiibia',
	'UserCountry_country_nc' => 'Uus-Kaledoonia',
	'UserCountry_country_ne' => 'Nigeeria',
	'UserCountry_country_nf' => 'Norfolki Saar',
	'UserCountry_country_ng' => 'Nigeeria',
	'UserCountry_country_ni' => 'Nikaraagua',
	'UserCountry_country_nl' => 'Holland',
	'UserCountry_country_no' => 'Norra',
	'UserCountry_country_np' => 'Nepaal',
	'UserCountry_country_nr' => 'Nauuru',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'Uus-Meremaa',
	'UserCountry_country_om' => 'Omaan',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peruu',
	'UserCountry_country_pf' => 'Prantsuse Polüneesia',
	'UserCountry_country_pg' => 'Papua Uus-Guinea',
	'UserCountry_country_ph' => 'Filipiinid',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Poola',
	'UserCountry_country_pm' => 'Saint Pierre ja Miquelon',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palestiina Territoorium',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguai',
	'UserCountry_country_qa' => 'Katar',
	'UserCountry_country_re' => 'Reunion Saar',
	'UserCountry_country_ro' => 'Romania',
	'UserCountry_country_rs' => 'Venemaa',
	'UserCountry_country_ru' => 'Vene Föderatsioon',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Saudi-Araabia',
	'UserCountry_country_sb' => 'Solomoni Saared',
	'UserCountry_country_sc' => 'Seitsellid',
	'UserCountry_country_sd' => 'Sudaan',
	'UserCountry_country_se' => 'Rootsi',
	'UserCountry_country_sg' => 'Singapur',
	'UserCountry_country_sh' => 'Püha Helena',
	'UserCountry_country_si' => 'Sloveenia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Slovakkia',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somaalia',
	'UserCountry_country_sr' => 'Suriname',
	'UserCountry_country_st' => 'Sao Tome ja Principe',
	'UserCountry_country_su' => 'Endine U.S.S.R',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Süüria Araabia vabariik',
	'UserCountry_country_sz' => 'Svaasimaa',
	'UserCountry_country_tc' => 'Turks ja Caicos',
	'UserCountry_country_td' => 'Tzaad',
	'UserCountry_country_tf' => 'Prantsuse Lõuna territooium',
	'UserCountry_country_tg' => 'Togomaa',
	'UserCountry_country_th' => 'Taimaa',
	'UserCountry_country_tj' => 'Tadzikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tm' => 'Türkmenistan',
	'UserCountry_country_tn' => 'Tuneesia',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'Ida Timor',
	'UserCountry_country_tr' => 'Türgi',
	'UserCountry_country_tt' => 'Trinidad ja Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzania, Ühendatud Rahvavabariik',
	'UserCountry_country_ua' => 'Ukraina',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Ühendatud kuningriigid',
	'UserCountry_country_um' => 'United States Minor Outlying Islands',
	'UserCountry_country_us' => 'Ameerika ühendriigid',
	'UserCountry_country_uy' => 'Uruguai',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Vatikani linn',
	'UserCountry_country_vc' => 'Püha Vincent ja Grenadiinid',
	'UserCountry_country_ve' => 'Venetsueela',
	'UserCountry_country_vg' => 'Virgin saared, Briti',
	'UserCountry_country_vi' => 'Virgin saared, U.S.',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis ja Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Jeemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Jugoslaavia',
	'UserCountry_country_za' => 'Lõuna Aafrika',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Sair',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Euroopa',
	'UserCountry_continent_afr' => 'Aafrika',
	'UserCountry_continent_asi' => 'Aasia',
	'UserCountry_continent_amn' => 'Põhja Ameerika',
	'UserCountry_continent_ams' => 'Lõuna ja Kesk Ameerika',
	'UserCountry_continent_oce' => 'Okeaania',
	'UserSettings_BrowserFamilies' => 'Sirvijate tüübid',
	'UserSettings_Browsers' => 'Veebisirvijad',
	'UserSettings_Plugins' => 'Pluginad',
	'UserSettings_Configurations' => 'Konfiguratsioonid',
	'UserSettings_OperatingSystems' => 'Operatsioonisüsteemid',
	'UserSettings_Resolutions' => 'Resolutsioonid',
	'UserSettings_WideScreen' => 'Laiekraan',
	'UserSettings_WidgetResolutions' => 'Ekraani resolutsioonid',
	'UserSettings_WidgetBrowsers' => 'Külastajate veebisirvijad',
	'UserSettings_WidgetPlugins' => 'Pluginate nimistu',
	'UserSettings_WidgetWidescreen' => 'Normaal / Laiekraan',
	'UserSettings_WidgetBrowserFamilies' => 'Sirvija tüübid',
	'UserSettings_WidgetOperatingSystems' => 'Operatsioonisüsteemid',
	'UserSettings_WidgetGlobalVisitors' => 'Kohalike külastajate seaded',
	'UserSettings_SubmenuSettings' => 'Seaded',
	'UsersManager_UsersManagement' => 'Kasutajate haldamine',
	'UsersManager_UsersManagementMainDescription' => 'Loo uusi kasutajakontosid või uuenda olemasolevaid. Saad seada nende õigused ülalpool.',
	'UsersManager_ManageAccess' => 'Halda ligipääsu',
	'UsersManager_MainDescription' => 'Otsusta millistel kasutajatel on ligipääs analüütikale. Saad seada õigused kõigile veebilehtedele korraga.',
	'UsersManager_Sites' => 'Saidid',
	'UsersManager_AllWebsites' => 'Kõik veebilehed',
	'UsersManager_ApplyToAllWebsites' => 'Laienda kõigile veebilehtedele',
	'UsersManager_User' => 'Kasutaja',
	'UsersManager_PrivNone' => 'Ligipääs puudub',
	'UsersManager_PrivView' => 'Vaata',
	'UsersManager_ChangeAllConfirm' => 'Kas sa oled kindel soovis anda \'%s\' õigused kõigile veebilehtedele?',
	'UsersManager_Password' => 'Salasõna',
	'UsersManager_Edit' => 'Muuda',
	'UsersManager_AddUser' => 'Lisa uus kasutaja',
	'UsersManager_MenuUsers' => 'Kasutajad',
	'UsersManager_DeleteConfirm_js' => 'Kas oled kindel, et soovid %s kustutada?',
	'UsersManager_ExceptionLoginExists' => 'Kasutajanimi \'%s\' on kasutusel.',
	'UsersManager_ExceptionEmailExists' => 'Sellise e-mailiga \'%s\' kasutaja on olemas.',
	'UsersManager_ExceptionInvalidEmail' => 'Emaili aadress ei ole õiges formaadis.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Kasutajat nimega \'%s\' ei eksisteeri seepärast ei saa teda ka kustutada.',
	'UsersManager_ExceptionAdminAnonymous' => 'Sa ei saa anda \'admin\' õiguseid \'anonymous\' kasutajale.',
	'UsersManager_ExceptionEditAnonymous' => 'Anonüümset kasutajat ei saa muuta ega kustutada. Piwik kasutab seda määratlemaks kasutajat, kes ei ole veel sisse loginud. Näiteks, saad teha statistika lubada \'view\' statistikat õigused \'anonymous\' kasutajale.',
	'UsersManager_ExceptionUserDoesNotExist' => 'Kasutaja \'%s\' puudub.',
	'VisitFrequency_Evolution' => 'Perioodi areng',
	'VisitFrequency_ReturnVisits' => '%s korduvat külastust',
	'VisitFrequency_ReturnActions' => '%s tegevust tegi korduv külastaja',
	'VisitFrequency_WidgetOverview' => 'Sageduse ülevaade',
	'VisitFrequency_WidgetGraphReturning' => 'Korduvate külastuste graafik',
	'VisitFrequency_SubmenuFrequency' => 'Sagedus',
	'VisitorInterest_WidgetLengths' => 'Külastuste kestvus',
	'VisitorInterest_WidgetPages' => 'Erinevaid lehti külastuse kohta',
	'VisitorInterest_OnePage' => '1 leht',
	'VisitorInterest_NPages' => '%s lehte',
	'VisitsSummary_NbVisits' => '%s külastust',
	'VisitsSummary_NbUniqueVisitors' => '%s unikaalset külastajat',
	'VisitsSummary_MaxNbActions' => '%s maksmimum tegevuste arv ühel külastusel',
	'VisitsSummary_GenerateTime' => 'Lehe genereerimiseks kulus %s sekundit',
	'VisitsSummary_GenerateQueries' => '%s katkestatud päringut',
	'VisitsSummary_WidgetLastVisits' => 'Viimaste külastuste graafik',
	'VisitsSummary_WidgetVisits' => 'Külastuste ülevaade',
	'VisitsSummary_WidgetLastVisitors' => 'Viimaste unikaalsete külastajate graafik',
	'VisitsSummary_WidgetOverviewGraph' => 'Graafikutega ülevaade',
	'VisitsSummary_SubmenuOverview' => 'Ülevaade',
	'VisitTime_LocalTime' => 'Külastused kohaliku kellaaja järgi',
	'VisitTime_ServerTime' => 'Külastused serveri kellaaja järgi',
	'VisitTime_WidgetLocalTime' => 'Külastused kohaliku kellaaja järgi',
	'VisitTime_WidgetServerTime' => 'Külastused serveri kellaaja järgi',
	'VisitTime_SubmenuTimes' => 'Korda',
	'VisitTime_NHour' => '%s',
);
